#!/bin/sh

# Script to check for the presence of packages needed by the Trinity Desktop
# Environment
#
# Copyright 2015 Simone Giustetti - Recco IT
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ''AS IS'' AND ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# -----------------------------------------------------------------------------
# Slackware Trinity source archive distribution script
# ========================================
# By:        Simone Giustetti <studiosg@giustetti.net>
# For:       TDE dependencies check script
# Changelog:
# 1.0       2015/01/21 by Simone Giustetti <studiosg@giustetti.net>
#           * Initial build.
#
# Run 'sh dependency_check.sh' to move source code archives into their proper
#   directory in the build tree.
#
# -----------------------------------------------------------------------------

# Log variable declaration & initialization
DATE_TIME=`date +%Y%m%d`
FILE_LOG="/tmp/dependency_check-${DATE_TIME}.log"
# Log variable declaration & initialization ends here

# Script root directory (Declared because of chroot)
DIR_ROOT="/usr/src/trinity/tde_build_script/"

# Configuration file location
FILE_CONF="${DIR_ROOT}/etc/tde_build.conf"
# Dependecies list
FILE_DEP="${DIR_ROOT}/etc/tde.dep"

# Define arrays
declare -a LIST_DEP_NAME
declare -a LIST_DEP_STATUS
declare COMPONENT_ALL=""


####  Main  ####
# Init the log file
echo "${DATE_TIME} - Dependency check in progress" | tee ${FILE_LOG}
# Move to the script direcotry
cd ${DIR_ROOT}

# Check for dependency file existence or exit
if [[ -r ${FILE_DEP} ]]; then
   echo "(II) Loading dependencies from file ${FILE_DEP}" | tee -a ${FILE_LOG}
   # Define arrays 1st component
   COUNTER_TOTAL=0
   # Load the dependency list from file ignoring comments
   while read DEP_NAME; do
      LIST_DEP_NAME[${COUNTER_TOTAL}]=${DEP_NAME}
      LIST_DEP_STATUS[${COUNTER_TOTAL}]="NO"
      # Component list update
      COMPONENT_ALL="${COMPONENT_ALL} ${COUNTER_TOTAL} "
      (( COUNTER_TOTAL=COUNTER_TOTAL+1 ))
   done <<< "$(cat ${FILE_DEP} | grep -v "#")"
else
   echo "(EE) ${FILE_DEP} does not exist or is not readable" | tee -a ${FILE_LOG}
   exit -51
fi

# Init the check status
CHECK_STATUS=0
# Check each individual package
for COMPONENT in ${COMPONENT_ALL}; do
   if [[ 0 -lt `ls /var/log/packages/${LIST_DEP_NAME[${COMPONENT}]}-* | wc -l` ]]; then
      LIST_DEP_STATUS[${COMPONENT}]="YES"
   else
      echo "(EE) No ${LIST_DEP_NAME[${COMPONENT}]} package found" | tee -a ${FILE_LOG}
      CHECK_STATUS=-52
   fi
echo ${LiST_DEP_STATUS[*]}
done

# Print out check outcome
echo "(II) Dependency check outcome:" | tee -a ${FILE_LOG}
for COMPONENT in ${COMPONENT_ALL}; do
   echo "(II) ${LIST_DEP_NAME[${COMPONENT}]} - ${LIST_DEP_STATUS[${COMPONENT}]}" | tee -a ${FILE_LOG}
done

# Return the check outcome and exit
echo "${DATE_TIME} - Dependency check successfully concluded" >> ${FILE_LOG}
exit ${CHECK_STATUS}
